encoder
=======

[![GoDoc](http://godoc.org/github.com//skycoin/skycoin/src/cipher/encoder?status.png)](http://godoc.org/github.com/skycoin/skycoin/src/cipher/encoder)

[Godoc generated documentation](https://godoc.org/github.com/skycoin/skycoin/src/cipher/encoder)

Binary struct encoder for Go.  Fork of go's pkg encoding/binary.
